﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class MonsterController : MonoBehaviour {

	public float baseHealth = 2, speed = 1, knockbackForce = 100, harmlessSpawnTime = .75f;
	private float currentHealth, spawnTime;

	public GameObject splatPrefab;

	private GameObject soulTank;
	public Transform target;

	public SpriteRenderer sprite;

	public bool hit = false;
	public int flashTimes = 16;

	void Start () {
		soulTank = GameObject.FindGameObjectWithTag ("SoulTank");
		target = GameObject.FindGameObjectWithTag ("Player").transform;
		currentHealth = baseHealth;
		spawnTime = Time.time;
		sprite = gameObject.GetComponent<SpriteRenderer> ();
	}
	
	void Update () {
		float step = speed * Time.deltaTime;
		transform.position = Vector2.MoveTowards (transform.position, target.position, step);
		if (hit && flashTimes > 0) {
			sprite.enabled = !sprite.enabled;
			flashTimes--;
		}
		if (flashTimes == 0) {
			flashTimes = 16;
			hit = false;
		}
	}

	void OnCollisionEnter2D(Collision2D col) {
		if (col.gameObject.CompareTag ("Player") && Time.time > spawnTime + harmlessSpawnTime) {
			PlayerController playerController = col.gameObject.GetComponent<PlayerController> ();
			if (playerController.invulnerable) {
				return;
			} else {
				playerController.TakeDamage ();
			}
		}
	}

	public void TakeDamage(float dmg = 1) {

		currentHealth -= dmg; 
		hit = true;
		var heading = target.position - transform.position;
		var direction = heading / heading.magnitude;
		gameObject.GetComponent<Rigidbody2D> ().AddForce (new Vector2 (direction.x * -knockbackForce, direction.y * -knockbackForce));

		if (currentHealth <= 0) {
			soulTank.GetComponent<SoulControl> ().gainSoul ();
			GameObject splatInstance = Instantiate (splatPrefab);
			splatInstance.transform.position = transform.position;
			Destroy(gameObject);
		}

	}
		
}
